==> esp8266-0.5.0.crate: esp8266-0.5.0/src/timer/frc2_int.rs <==
#[doc = "Register `FRC2_INT` reader"]
pub struct R(crate::R<FRC2_INT_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FRC2_INT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<FRC2_INT_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<FRC2_INT_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `FRC2_INT` writer"]
pub struct W(crate::W<FRC2_INT_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<FRC2_INT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<FRC2_INT_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<FRC2_INT_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `frc2_int_clr_mask` reader - write to clear the status of the interrupt, if theinterrupt type is \"level\""]
pub struct FRC2_INT_CLR_MASK_R(crate::FieldReader<bool, bool>);
impl FRC2_INT_CLR_MASK_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        FRC2_INT_CLR_MASK_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FRC2_INT_CLR_MASK_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `frc2_int_clr_mask` writer - write to clear the status of the interrupt, if theinterrupt type is \"level\""]
pub struct FRC2_INT_CLR_MASK_W<'a> {
    w: &'a mut W,
}
impl<'a> FRC2_INT_CLR_MASK_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
        self.w
    }
}
impl R {
    #[doc = "Bit 0 - write to clear the status of the interrupt, if theinterrupt type is \"level\""]
    #[inline(always)]
    pub fn frc2_int_clr_mask(&self) -> FRC2_INT_CLR_MASK_R {
        FRC2_INT_CLR_MASK_R::new((self.bits & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bit 0 - write to clear the status of the interrupt, if theinterrupt type is \"level\""]
    #[inline(always)]
    pub fn frc2_int_clr_mask(&mut self) -> FRC2_INT_CLR_MASK_W {
        FRC2_INT_CLR_MASK_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "FRC2_INT\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc2_int]
(index.html) module"]
pub struct FRC2_INT_SPEC;
impl crate::RegisterSpec for FRC2_INT_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [frc2_int::R]
(R) reader structure"]
impl crate::Readable for FRC2_INT_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [frc2_int::W]
(W) writer structure"]
impl crate::Writable for FRC2_INT_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets FRC2_INT to value 0"]
impl crate::Resettable for FRC2_INT_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.6.0.crate: esp8266-0.6.0/src/timer/frc2_int.rs <==
#[doc = "Register `FRC2_INT` reader"]
pub struct R(crate::R<FRC2_INT_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FRC2_INT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<FRC2_INT_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<FRC2_INT_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `FRC2_INT` writer"]
pub struct W(crate::W<FRC2_INT_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<FRC2_INT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<FRC2_INT_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<FRC2_INT_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `frc2_int_clr_mask` reader - write to clear the status of the interrupt, if theinterrupt type is \"level\""]
pub struct FRC2_INT_CLR_MASK_R(crate::FieldReader<bool, bool>);
impl FRC2_INT_CLR_MASK_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        FRC2_INT_CLR_MASK_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FRC2_INT_CLR_MASK_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `frc2_int_clr_mask` writer - write to clear the status of the interrupt, if theinterrupt type is \"level\""]
pub struct FRC2_INT_CLR_MASK_W<'a> {
    w: &'a mut W,
}
impl<'a> FRC2_INT_CLR_MASK_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
        self.w
    }
}
impl R {
    #[doc = "Bit 0 - write to clear the status of the interrupt, if theinterrupt type is \"level\""]
    #[inline(always)]
    pub fn frc2_int_clr_mask(&self) -> FRC2_INT_CLR_MASK_R {
        FRC2_INT_CLR_MASK_R::new((self.bits & 1) != 0)
    }
}
impl W {
    #[doc = "Bit 0 - write to clear the status of the interrupt, if theinterrupt type is \"level\""]
    #[inline(always)]
    pub fn frc2_int_clr_mask(&mut self) -> FRC2_INT_CLR_MASK_W {
        FRC2_INT_CLR_MASK_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "FRC2_INT\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc2_int]
(index.html) module"]
pub struct FRC2_INT_SPEC;
impl crate::RegisterSpec for FRC2_INT_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [frc2_int::R]
(R) reader structure"]
impl crate::Readable for FRC2_INT_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [frc2_int::W]
(W) writer structure"]
impl crate::Writable for FRC2_INT_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets FRC2_INT to value 0"]
impl crate::Resettable for FRC2_INT_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
